import { Badge } from "./ui/badge";
import {
  Card,
  CardContent,
  CardFooter,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import image from "../assets/growth.png";
import image3 from "../assets/reflecting.png";
import image4 from "../assets/looking-ahead.png";
import {useEffect, useState} from "react";
import {extractSubstring} from "@/services/api.ts";
import axios from "axios";

interface FeatureProps {
  title: string;
  description: string;
  image: string;
}

let features: FeatureProps[] = [];

// const features: FeatureProps[] = [
//   {
//     title: "Responsive Design",
//     description:
//       "Lorem ipsum dolor sit amet consectetur adipisicing elit. Nisi nesciunt est nostrum omnis ab sapiente.",
//     image: image4,
//   },
//   {
//     title: "Intuitive user interface",
//     description:
//       "Lorem ipsum dolor sit amet consectetur adipisicing elit. Nisi nesciunt est nostrum omnis ab sapiente.",
//     image: image3,
//   },
//   {
//     title: "AI-Powered insights",
//     description:
//       "Lorem ipsum dolor sit amet consectetur adipisicing elit. Nisi nesciunt est nostrum omnis ab sapiente.",
//     image: image,
//   },
// ];
const imageList = [image, image3, image4];
const featureList: string[] = [
  "Dark/Light theme",
  "Reviews",
  "Features",
  "Pricing",
  "Contact form",
  "Our team",
  "Responsive design",
  "Newsletter",
  "Minimalist",
];

export const Features = () => {
  const [loading, setLoading] = useState(true);
  useEffect(() => {
    // 使用 axios 进行 API 调用
    const fetchData = async () => {
      try {
        const websiteCode = extractSubstring(window.location.pathname);
        const response = await axios.get('/api/website/template/getWebsiteByWebsiteCode', {
          params: {
            websiteCode: websiteCode
          }
        });
        const userWebsiteId = response.data.data.id;
        const response2 = await axios.get('/api/website/template/products', {
          params: {
            userWebsiteId: userWebsiteId
          }
        });
        features = response2.data.data.map((item, index) => {
          return {
            title: item.name,
            description: item.description.substring(0, 200) + '...',
            image: imageList[index % imageList.length],
          }
        })
      } catch (err) {
        console.error('Error fetching data:', err);
      } finally {
        setLoading(false);
      }
    };

    fetchData();

  }, []);
  // 处理加载和错误状态
  if (loading) {
    return <div>Loading...</div>;
  }
  return (
    <section
      id="features"
      className="container py-24 sm:py-32 space-y-8"
    >
      <h2 className="text-3xl lg:text-4xl font-bold md:text-center">
        Many{" "}
        <span className="bg-gradient-to-b from-primary/60 to-primary text-transparent bg-clip-text">
          Great Products
        </span>
      </h2>

      <div className="flex flex-wrap md:justify-center gap-4">
        {featureList.map((feature: string) => (
          <div key={feature}>
            <Badge
              variant="secondary"
              className="text-sm"
            >
              {feature}
            </Badge>
          </div>
        ))}
      </div>

      <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
        {features.map(({ title, description, image }: FeatureProps) => (
          <Card key={title}>
            <CardHeader>
              <CardTitle>{title}</CardTitle>
            </CardHeader>

            <CardContent>{description}</CardContent>

            <CardFooter>
              <img
                src={image}
                alt="About feature"
                className="w-[200px] lg:w-[300px] mx-auto"
              />
            </CardFooter>
          </Card>
        ))}
      </div>
    </section>
  );
};

