import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { LightBulbIcon } from "./Icons";
import Logo from "../assets/logo.png";
import {useEffect, useState} from "react";
import {extractSubstring} from "@/services/api.ts";
import axios from "axios";

export const HeroCards = () => {
  const [product1, setProduct1] = useState(null);
  const [description1, setDescription1] = useState(null);
  const [product2, setProduct2] = useState(null);
  const [description2, setDescription2] = useState(null);
  useEffect(() => {
    // 使用 axios 进行 API 调用
    const fetchData = async () => {
      try {
        const websiteCode = extractSubstring(window.location.pathname);
        const response = await axios.get('/api/website/template/getWebsiteByWebsiteCode', {
          params: {
            websiteCode: websiteCode
          }
        });
        const userWebsiteId = response.data.data.id;
        const response2 = await axios.get('/api/website/template/products', {
          params: {
            userWebsiteId: userWebsiteId
          }
        });
        if (response2.data.data.length > 0) {
          setProduct1(response2.data.data[0].name);
          setDescription1(response2.data.data[0].description);
          setProduct2(response2.data.data[1].name);
          setDescription2(response2.data.data[1].description);
        }
      } catch (err) {
        console.error('Error fetching data:', err);
      }
    };

    fetchData();

  }, []);
  return (
    <div className="hidden lg:flex flex-row flex-wrap gap-8 relative w-[700px] h-[500px]">
      {/* Testimonial */}
      <Card className="absolute w-[340px] -top-[15px] drop-shadow-xl shadow-black/10 dark:shadow-white/10">
        <CardHeader className="space-y-1 flex md:flex-row justify-start items-start gap-4">
          <div className="mt-1 bg-primary/20 p-1 rounded-2xl">
            <LightBulbIcon />
          </div>
          <div>
            <CardTitle>Light & dark mode</CardTitle>
            <CardDescription className="text-md mt-2">
              Lorem ipsum dolor sit amet consect adipisicing elit. Consectetur
              natusm.
            </CardDescription>
          </div>
        </CardHeader>
      </Card>

      {/* Team */}
      <Card className="absolute right-[20px] top-4 w-80 flex flex-col justify-center items-center drop-shadow-xl shadow-black/10 dark:shadow-white/10">
        <CardHeader className="mt-8 flex justify-center items-center pb-2">
          <img
            src={Logo}
            alt="user avatar"
            className="absolute grayscale-[0%] -top-12 rounded-full w-24 h-24 aspect-square object-cover"
          />
          <CardTitle className="text-center">{product1}</CardTitle>
        </CardHeader>

        <CardContent className="text-center pb-2">
          <p>
            {description1}
          </p>
        </CardContent>
      </Card>

      {/* Pricing */}
      <Card className="absolute top-[200px] left-[50px] w-72  drop-shadow-xl shadow-black/10 dark:shadow-white/10">
        <CardHeader>
          <CardTitle className="flex item-center justify-between">
            {product2}
          </CardTitle>
          <CardDescription>
            {description2}
          </CardDescription>
        </CardHeader>
      </Card>
    </div>
  );
};
