import {useEffect, useState} from "react";
import {extractSubstring} from "@/services/api.ts";
import axios from "axios";

export const Statistics = () => {
  const [loading, setLoading] = useState(true);
  let stats: statsProps[] = [];
  useEffect(() => {
    // 使用 axios 进行 API 调用
    const fetchData = async () => {
      try {
        const websiteCode = extractSubstring(window.location.pathname);
        const response = await axios.get('/api/website/template/getWebsiteByWebsiteCode', {
          params: {
            websiteCode: websiteCode
          }
        });
        const userWebsiteId = response.data.data.id;
        const response2 = await axios.get('/api/website/template/company', {
          params: {
            userWebsiteId: userWebsiteId
          }
        });
        stats = [
          {
            quantity: response2.data.data.userNum,
            description: "Users",
          },
          {
            quantity: response2.data.data.factorySpace,
            description: "Factory Space",
          },
          {
            quantity: response2.data.data.establishYear,
            description: "Establish Year",
          },
          {
            quantity: response2.data.data.productNum,
            description: "Products",
          },
        ];
      } catch (err) {
        console.error('Error fetching data:', err);
      } finally {
        setLoading(false);
      }
    };

    fetchData();

  }, []);
  // 处理加载和错误状态
  if (loading) {
    return <div>Loading...</div>;
  }
  interface statsProps {
    quantity: string;
    description: string;
  }

  return (
    <section id="statistics">
      <div className="grid grid-cols-2 lg:grid-cols-4 gap-8">
        {stats.map(({ quantity, description }: statsProps) => (
          <div
            key={description}
            className="space-y-2 text-center"
          >
            <h2 className="text-3xl sm:text-4xl font-bold ">{quantity}</h2>
            <p className="text-xl text-muted-foreground">{description}</p>
          </div>
        ))}
      </div>
    </section>
  );
};
